package main

import (
	"fmt"
	"log"
	"strconv"

	"github.com/gdamore/tcell/v2"
)

func updateScore(screen tcell.Screen, style tcell.Style, score int) {
	var x, y int
	_, y = screen.Size()
	x = 5
	for _, r := range []rune("[ Score: " + strconv.FormatInt(int64(score), 10) + " ]") {
		screen.SetContent(x, y-1, r, nil, style)
		x++
	}
}

func drawBox(s tcell.Screen, x1, y1, x2, y2 int, style tcell.Style) {
	if y2 < y1 {
		y1, y2 = y2, y1
	}
	if x2 < x1 {
		x1, x2 = x2, x1
	}

	// Fill background
	for row := y1; row <= y2; row++ {
		for col := x1; col <= x2; col++ {
			s.SetContent(col, row, ' ', nil, style)
		}
	}

	// Draw borders
	for col := x1; col <= x2; col++ {
		s.SetContent(col, y1, '═', nil, style)
		s.SetContent(col, y2, '═', nil, style)
	}
	for row := y1 + 1; row < y2; row++ {
		s.SetContent(x1, row, '║', nil, style)
		s.SetContent(x2, row, '║', nil, style)
	}

	// Only draw corners if necessary
	if y1 != y2 && x1 != x2 {
		s.SetContent(x1, y1, '╔', nil, style)
		s.SetContent(x2, y1, '╗', nil, style)
		s.SetContent(x1, y2, '╚', nil, style)
		s.SetContent(x2, y2, '╝', nil, style)
	}

	//drawText(s, x1+1, y1+1, x2-1, y2-1, style, text)
	updateScore(s, style, 10)
}

func main() {

	defaultStyle := tcell.StyleDefault.Background(tcell.ColorReset).Foreground(tcell.ColorReset)

	var err error

	screen, err := tcell.NewScreen()
	if err != nil {
		log.Println("Error creating screen: ", err)
	}
	err = screen.Init()
	if err != nil {
		log.Fatalln("Error initializing screen: ", err)
	}

	x, y := screen.Size()

	screen.Clear()

	drawBox(screen, 0, 0, x-1, y-1, defaultStyle)

	quit := func() {
		// You have to catch panics in a defer, clean up, and
		// re-raise them - otherwise your application can
		// die without leaving any diagnostic trace.
		maybePanic := recover()
		screen.Fini()
		if maybePanic != nil {
			panic(maybePanic)
		}
	}
	defer quit()

	for {
		screen.Show()
		ev := screen.PollEvent()
		switch ev := ev.(type) {
		case *tcell.EventResize:
			x, y := screen.Size()
			drawBox(screen, 0, 0, x-1, y-1, defaultStyle)
			fmt.Println("size=ok:", checkSize(screen))
			screen.Sync()
		case *tcell.EventKey:
			//fmt.Println("Key: ",ev.Rune())
			if ev.Key() == tcell.KeyEscape || ev.Key() == tcell.KeyCtrlC {
				return
			} else if ev.Rune() == 'q' || ev.Rune() == 'Q' {
				return
			} else if ev.Key() == tcell.KeyCtrlL {
				screen.Sync()
			} else if ev.Rune() == 'C' || ev.Rune() == 'c' {
				screen.Clear()
			}
		}
	}
}
